==> cms-db_v0.5.1.tar.gz: admin/backup_complete.php <==
<?php
/*  cms-db  Copyright (C) 2007-2008 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
session_start();
include("session.inc.php");
if ($_SESSION['CMS-Login'] == "LOGEDIN" OR $session == false) {
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title>CMS Inhalt</title>
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1>Komplettes Backup</h1>

<?php
function createFileBackup($ordner, $data = array()) {
	$handle = opendir($ordner);
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			if(is_dir($ordner."/".$file)) {
				$data = createFileBackup($ordner."/".$file, $data);
			} elseif ($ordner.'/'.$file != '../data/version.txt') {
				$data[] = $ordner."/".$file;
			}
		}
	}
	closedir($handle);
	return $data;
}

include("./pclzip-2-6/pclzip.lib.php");
$zip = new PclZip('../data/backup/backup_complete.zip');
$files = createFileBackup("../data");
$list = $zip->create($files,
	PCLZIP_OPT_REMOVE_PATH, '../data',
	PCLZIP_OPT_ADD_PATH, 'cms-db_backup_complete_v0.5');
if ($list == 0) {
	die('Fehler: '.$zip->errorInfo(true));
}
?>
<p>
	Das Backup wurde erstellt.
</p>
<p>
	<a href="../data/backup/backup_complete.zip">herunterladen</a>
</p>
<p>
	<a href="backup.php?<?php echo SID ?>">zur&uuml;ck</a>	
</p>

</body>
</html>
<?php
} else {
header("Location:index.php");
}
?>

==> cms-db_v0.6.tar.gz: admin/backup_complete.php <==
<?php
/*  cms-db  Copyright (C) 2007-2009 Jan Hoffmann
    This program comes with ABSOLUTELY NO WARRANTY; for details see /admin/version.php.
    This is free software, and you are welcome to redistribute it under certain conditions; see /admin/version.php for details.  */
include('checkuser.inc.php');
checkuser('');
include('locale.inc.php');
$locale = new LocalizingClass('backup-action');
?>
<!DOCTYPE html PUBLIC "-//W3C//DTD XHTML 1.0 Strict//EN"
     "http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd">
<html xmlns="http://www.w3.org/1999/xhtml">
<head>
<title><?php locale('title_backup-complete') ?></title>
<meta http-equiv="content-type" content="text/html; charset=utf-8" />
<link rel="stylesheet" type="text/css" href="style.css">
</head>
<body>

<h1><?php locale('title_backup-complete') ?></h1>

<?php
$handle = opendir('../data/backup');
while (false !== ($file = readdir ($handle))) {
	if ($file != "." && $file != "..") {
		unlink('../data/backup/'.$file);
	}
}
closedir($handle);

function createFileBackup($ordner, $data = array()) {
	$handle = opendir($ordner);
	while (false !== ($file = readdir($handle))) {
		if($file != "." && $file != "..") {
			if(is_dir($ordner."/".$file)) {
				$data = createFileBackup($ordner."/".$file, $data);
			} elseif ($ordner.'/'.$file != '../data/version.txt') {
				$data[] = $ordner."/".$file;
			}
		}
	}
	closedir($handle);
	return $data;
}

include("./pclzip-2-6/pclzip.lib.php");
$zip = new PclZip('../data/backup/backup_complete.zip');
$files = createFileBackup("../data");
$list = $zip->create($files,
	PCLZIP_OPT_REMOVE_PATH, '../data',
	PCLZIP_OPT_ADD_PATH, 'cms-db_backup_complete_v0.5');
if ($list == 0) {
	die('Fehler: '.$zip->errorInfo(true));
}
?>
<p>
	<?php locale('desc_backup-ready') ?>
</p>
<p>
	<a href="../data/backup/backup_complete.zip"><?php locale('link_backup-download') ?></a>
</p>
<p>
	<a href="backup.php?<?php echo SID ?>"><?php locale('link_back') ?></a>	
</p>

</body>
</html>
